@@ -50,7 +50,7 @@ pub struct WebViewAttributes {
   /// closure.
   ///
   /// The closure takes the `Window` and a url string slice as parameters, and returns a tuple of a
-  /// vector of bytes which is the content and a mimetype string of the conten.
+  /// vector of bytes which is the content and a mimetype string of the content.
   pub custom_protocols: Vec<(
     String,
     Box<dyn Fn(&Window, &str) -> Result<(Vec<u8>, String)>>,
@@ -141,7 +141,7 @@ impl<'a> WebViewBuilder<'a> {
   /// closure.
   ///
   /// The closure takes the `Window` and a url string slice as parameters, and returns a tuple of a
-  /// vector of bytes which is the content and a mimetype string of the conten.
+  /// vector of bytes which is the content and a mimetype string of the content.
   #[cfg(feature = "protocol")]
   pub fn with_custom_protocol<F>(mut self, name: String, handler: F) -> Self
   where
@@ -285,10 +285,10 @@ pub struct WebView {
 impl Drop for WebView {
   fn drop(&mut self) {
     #[cfg(target_os = "linux")]
-    {
+    unsafe {
       use crate::application::platform::unix::WindowExtUnix;
-      use gtk::GtkWindowExt;
-      self.window.gtk_window().close();
+      use gtk::prelude::WidgetExtManual;
+      self.window().gtk_window().destroy();
     }
     #[cfg(target_os = "windows")]
     unsafe {
@@ -344,6 +344,16 @@ impl WebView {
     self.webview.resize(self.window.hwnd())?;
     Ok(())
   }
+
+  /// Moves Focus to the Webview control.
+  ///
+  /// It's usually safe to call `focus` method on `Window` which would also focus to `WebView` except Windows.
+  /// Focussing to `Window` doesn't mean focussing to `WebView` on Windows. For example, if you have
+  /// an input field on webview and lost focus, you will have to explicitly click the field even you
+  /// re-focus the window. And if you focus to `WebView`, it will lost focus to the `Window`.
+  pub fn focus(&self) {
+    self.webview.focus();
+  }
 }
 
 // Helper so all platforms handle RPC messages consistently.
@@ -443,6 +453,7 @@ impl RpcResponse {
 }
 
 /// An event enumeration sent to [`FileDropHandler`].
+#[non_exhaustive]
 #[derive(Debug, Serialize, Clone)]
 pub enum FileDropEvent {
   /// The file(s) have been dragged onto the window, but have not been dropped yet.
@@ -458,6 +469,20 @@ pub fn webview_version() -> Result<String> {
   platform_webview_version()
 }
 
+/// Additional methods on `WebView` that are specific to Windows.
+#[cfg(target_os = "windows")]
+pub trait WebviewExtWindows {
+  /// Returns WebView2 Controller
+  fn controller(&self) -> Option<&::webview2::Controller>;
+}
+
+#[cfg(target_os = "windows")]
+impl WebviewExtWindows for WebView {
+  fn controller(&self) -> Option<&::webview2::Controller> {
+    self.webview.controller.get()
+  }
+}
+
 #[cfg(test)]
 mod tests {
   use super::*;
